@@ -37,6 +37,12 @@ class Item(Object, openable_mixin):
             assoc.item=self
         return assocs
 
+    @property
+    @lazy
+    def files(self):
+        return [x.file for x in self.file_associations]
+    
+
     @property
     @lazy
     def thumbnail(self):
@@ -87,7 +93,9 @@ class ItemFileAssociation(Object):
     @property
     @lazy
     def file(self):
-        return self._client.File(self.__dict__['file']['guid'])
+        f= self._client.File(self.__dict__['file']['guid'])
+        f._client=self._client
+        return f
 
     @property
     def endpoint(self):
